@@ -1,6 +1,7 @@
 import requests
+from requests.exceptions import HTTPError
 
-from freshdesk.models import Ticket
+from freshdesk.models import *
 
 class TicketAPI(object):
     def __init__(self, api):
@@ -8,7 +9,7 @@ class TicketAPI(object):
 
     def get_ticket(self, ticket_id):
         """Fetches the ticket for the given ticket ID"""
-        url = 'tickets/%d.json' % ticket_id
+        url = 'helpdesk/tickets/%d.json' % ticket_id
         return Ticket(**self._api._get(url)['helpdesk_ticket'])
 
     def list_tickets(self, **kwargs):
@@ -21,10 +22,12 @@ class TicketAPI(object):
         Multiple filters are AND'd together.
         """
 
-        if 'filter_name' not in kwargs:
-            kwargs['filter_name'] = 'all_tickets'
+        filter_name = 'all_tickets'
+        if 'filter_name' in kwargs:
+            filter_name = kwargs['filter_name']
+            del kwargs['filter_name']
 
-        url = 'tickets/filter/%s?format=json' % kwargs['filter_name']
+        url = 'helpdesk/tickets/filter/%s?format=json' % filter_name
         page = 1
         tickets = []
 
@@ -50,6 +53,14 @@ class TicketAPI(object):
         """Lists all deleted tickets."""
         return self.list_tickets(filter_name='deleted')
 
+class ContactAPI(object):
+    def __init__(self, api):
+        self._api = api
+
+    def get_contact(self, contact_id):
+        url = 'contacts/%s.json' % contact_id
+        return Contact(**self._api._get(url)['user'])
+
 class API(object):
     def __init__(self, domain, api_key):
         """Creates a wrapper to perform API actions.
@@ -62,22 +73,22 @@ class API(object):
           .tickets:  the Ticket API
         """
 
-        if domain[-1] == '/':
-            domain[-1] = ''
-        self._api_prefix = 'http://{}/helpdesk/'.format(domain)
-
+        self._api_prefix = 'http://{}/'.format(domain.rstrip('/'))
         self._session = requests.Session()
         self._session.auth = (api_key, 'unused_with_api_key')
         self._session.headers = {'Content-Type': 'application/json'}
 
         self.tickets = TicketAPI(self)
+        self.contacts = ContactAPI(self)
 
     def _get(self, url, params={}):
         """Wrapper around request.get() to use the API prefix. Returns a JSON response."""
         r = self._session.get(self._api_prefix + url, params=params)
         r.raise_for_status()
+        if 'Retry-After' in r.headers:
+            raise HTTPError('403 Forbidden: API rate-limit has been reached until {}.' \
+                    'See http://freshdesk.com/api#ratelimit'.format(r.headers['Retry-After']))
         j = r.json()
         if 'require_login' in j:
-            from requests.exceptions import HTTPError
             raise HTTPError('403 Forbidden: API key is incorrect for this domain')
         return r.json()
